"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeyPair = void 0;
const tuf = __importStar(require("@tufjs/models"));
const crypto_1 = require("./crypto");
class KeyPair {
    privateKey;
    publicKey;
    constructor() {
        const { privateKey, publicKey } = (0, crypto_1.generateKeyPair)();
        this.privateKey = privateKey;
        this.publicKey = toPublicKeyMeta(publicKey);
    }
    sign(data) {
        const sig = (0, crypto_1.signSHA256)(this.privateKey, data);
        return new tuf.Signature({ keyID: this.publicKey.keyID, sig });
    }
}
exports.KeyPair = KeyPair;
function toPublicKeyMeta(publicKey) {
    const meta = {
        keyType: 'ecdsa-sha2-nistp256',
        scheme: 'ecdsa-sha2-nistp256',
        keyVal: {
            public: publicKey.export({ format: 'pem', type: 'spki' }).toString(),
        },
    };
    const canonical = JSON.stringify(meta);
    const keyid = (0, crypto_1.digestSHA256)(canonical);
    return new tuf.Key({ keyID: keyid, ...meta });
}
